==> zio-aws-ec2_2.13-5.17.295.2-sources.jar: zio/aws/ec2/model/RevokeSecurityGroupEgressRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, SecurityGroupId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RevokeSecurityGroupEgressRequest(
    groupId: SecurityGroupId,
    ipPermissions: Optional[Iterable[zio.aws.ec2.model.IpPermission]] =
      Optional.Absent,
    securityGroupRuleIds: Optional[Iterable[String]] = Optional.Absent,
    cidrIp: Optional[String] = Optional.Absent,
    fromPort: Optional[Integer] = Optional.Absent,
    ipProtocol: Optional[String] = Optional.Absent,
    toPort: Optional[Integer] = Optional.Absent,
    sourceSecurityGroupName: Optional[String] = Optional.Absent,
    sourceSecurityGroupOwnerId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest = {
    import RevokeSecurityGroupEgressRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest
      .builder()
      .groupId(SecurityGroupId.unwrap(groupId): java.lang.String)
      .optionallyWith(
        ipPermissions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.ipPermissions)
      .optionallyWith(
        securityGroupRuleIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroupRuleIds)
      .optionallyWith(cidrIp.map(value => value: java.lang.String))(_.cidrIp)
      .optionallyWith(fromPort.map(value => value: java.lang.Integer))(
        _.fromPort
      )
      .optionallyWith(ipProtocol.map(value => value: java.lang.String))(
        _.ipProtocol
      )
      .optionallyWith(toPort.map(value => value: java.lang.Integer))(_.toPort)
      .optionallyWith(
        sourceSecurityGroupName.map(value => value: java.lang.String)
      )(_.sourceSecurityGroupName)
      .optionallyWith(
        sourceSecurityGroupOwnerId.map(value => value: java.lang.String)
      )(_.sourceSecurityGroupOwnerId)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.RevokeSecurityGroupEgressRequest.ReadOnly =
    zio.aws.ec2.model.RevokeSecurityGroupEgressRequest.wrap(buildAwsValue())
}
object RevokeSecurityGroupEgressRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.RevokeSecurityGroupEgressRequest =
      zio.aws.ec2.model.RevokeSecurityGroupEgressRequest(
        groupId,
        ipPermissions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        securityGroupRuleIds.map(value => value),
        cidrIp.map(value => value),
        fromPort.map(value => value),
        ipProtocol.map(value => value),
        toPort.map(value => value),
        sourceSecurityGroupName.map(value => value),
        sourceSecurityGroupOwnerId.map(value => value)
      )
    def groupId: SecurityGroupId
    def ipPermissions: Optional[List[zio.aws.ec2.model.IpPermission.ReadOnly]]
    def securityGroupRuleIds: Optional[List[String]]
    def cidrIp: Optional[String]
    def fromPort: Optional[Integer]
    def ipProtocol: Optional[String]
    def toPort: Optional[Integer]
    def sourceSecurityGroupName: Optional[String]
    def sourceSecurityGroupOwnerId: Optional[String]
    def getGroupId: ZIO[Any, Nothing, SecurityGroupId] = ZIO.succeed(groupId)
    def getIpPermissions
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.IpPermission.ReadOnly]] =
      AwsError.unwrapOptionField("ipPermissions", ipPermissions)
    def getSecurityGroupRuleIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("securityGroupRuleIds", securityGroupRuleIds)
    def getCidrIp: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("cidrIp", cidrIp)
    def getFromPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("fromPort", fromPort)
    def getIpProtocol: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipProtocol", ipProtocol)
    def getToPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("toPort", toPort)
    def getSourceSecurityGroupName: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("sourceSecurityGroupName", sourceSecurityGroupName)
    def getSourceSecurityGroupOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "sourceSecurityGroupOwnerId",
        sourceSecurityGroupOwnerId
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest
  ) extends zio.aws.ec2.model.RevokeSecurityGroupEgressRequest.ReadOnly {
    override val groupId: SecurityGroupId =
      zio.aws.ec2.model.primitives.SecurityGroupId(impl.groupId())
    override val ipPermissions
        : Optional[List[zio.aws.ec2.model.IpPermission.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipPermissions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.IpPermission.wrap(item)
          }.toList
        )
    override val securityGroupRuleIds: Optional[List[String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.securityGroupRuleIds())
        .map(value =>
          value.asScala.map { item =>
            item: String
          }.toList
        )
    override val cidrIp: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.cidrIp())
      .map(value => value: String)
    override val fromPort: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.fromPort())
      .map(value => value: Integer)
    override val ipProtocol: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.ipProtocol())
      .map(value => value: String)
    override val toPort: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.toPort())
      .map(value => value: Integer)
    override val sourceSecurityGroupName: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourceSecurityGroupName())
        .map(value => value: String)
    override val sourceSecurityGroupOwnerId: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourceSecurityGroupOwnerId())
        .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest
  ): zio.aws.ec2.model.RevokeSecurityGroupEgressRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-7.21.15.12-sources.jar: zio/aws/ec2/model/RevokeSecurityGroupEgressRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, SecurityGroupId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RevokeSecurityGroupEgressRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    groupId: SecurityGroupId,
    ipPermissions: Optional[Iterable[zio.aws.ec2.model.IpPermission]] =
      Optional.Absent,
    securityGroupRuleIds: Optional[Iterable[String]] = Optional.Absent,
    cidrIp: Optional[String] = Optional.Absent,
    fromPort: Optional[Integer] = Optional.Absent,
    ipProtocol: Optional[String] = Optional.Absent,
    toPort: Optional[Integer] = Optional.Absent,
    sourceSecurityGroupName: Optional[String] = Optional.Absent,
    sourceSecurityGroupOwnerId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest = {
    import RevokeSecurityGroupEgressRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .groupId(SecurityGroupId.unwrap(groupId): java.lang.String)
      .optionallyWith(
        ipPermissions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.ipPermissions)
      .optionallyWith(
        securityGroupRuleIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroupRuleIds)
      .optionallyWith(cidrIp.map(value => value: java.lang.String))(_.cidrIp)
      .optionallyWith(fromPort.map(value => value: java.lang.Integer))(
        _.fromPort
      )
      .optionallyWith(ipProtocol.map(value => value: java.lang.String))(
        _.ipProtocol
      )
      .optionallyWith(toPort.map(value => value: java.lang.Integer))(_.toPort)
      .optionallyWith(
        sourceSecurityGroupName.map(value => value: java.lang.String)
      )(_.sourceSecurityGroupName)
      .optionallyWith(
        sourceSecurityGroupOwnerId.map(value => value: java.lang.String)
      )(_.sourceSecurityGroupOwnerId)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.RevokeSecurityGroupEgressRequest.ReadOnly =
    zio.aws.ec2.model.RevokeSecurityGroupEgressRequest.wrap(buildAwsValue())
}
object RevokeSecurityGroupEgressRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.RevokeSecurityGroupEgressRequest =
      zio.aws.ec2.model.RevokeSecurityGroupEgressRequest(
        dryRun.map(value => value),
        groupId,
        ipPermissions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        securityGroupRuleIds.map(value => value),
        cidrIp.map(value => value),
        fromPort.map(value => value),
        ipProtocol.map(value => value),
        toPort.map(value => value),
        sourceSecurityGroupName.map(value => value),
        sourceSecurityGroupOwnerId.map(value => value)
      )
    def dryRun: Optional[Boolean]
    def groupId: SecurityGroupId
    def ipPermissions: Optional[List[zio.aws.ec2.model.IpPermission.ReadOnly]]
    def securityGroupRuleIds: Optional[List[String]]
    def cidrIp: Optional[String]
    def fromPort: Optional[Integer]
    def ipProtocol: Optional[String]
    def toPort: Optional[Integer]
    def sourceSecurityGroupName: Optional[String]
    def sourceSecurityGroupOwnerId: Optional[String]
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getGroupId: ZIO[Any, Nothing, SecurityGroupId] = ZIO.succeed(groupId)
    def getIpPermissions
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.IpPermission.ReadOnly]] =
      AwsError.unwrapOptionField("ipPermissions", ipPermissions)
    def getSecurityGroupRuleIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("securityGroupRuleIds", securityGroupRuleIds)
    def getCidrIp: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("cidrIp", cidrIp)
    def getFromPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("fromPort", fromPort)
    def getIpProtocol: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipProtocol", ipProtocol)
    def getToPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("toPort", toPort)
    def getSourceSecurityGroupName: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("sourceSecurityGroupName", sourceSecurityGroupName)
    def getSourceSecurityGroupOwnerId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "sourceSecurityGroupOwnerId",
        sourceSecurityGroupOwnerId
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest
  ) extends zio.aws.ec2.model.RevokeSecurityGroupEgressRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val groupId: SecurityGroupId =
      zio.aws.ec2.model.primitives.SecurityGroupId(impl.groupId())
    override val ipPermissions
        : Optional[List[zio.aws.ec2.model.IpPermission.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipPermissions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.IpPermission.wrap(item)
          }.toList
        )
    override val securityGroupRuleIds: Optional[List[String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.securityGroupRuleIds())
        .map(value =>
          value.asScala.map { item =>
            item: String
          }.toList
        )
    override val cidrIp: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.cidrIp())
      .map(value => value: String)
    override val fromPort: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.fromPort())
      .map(value => value: Integer)
    override val ipProtocol: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.ipProtocol())
      .map(value => value: String)
    override val toPort: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.toPort())
      .map(value => value: Integer)
    override val sourceSecurityGroupName: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourceSecurityGroupName())
        .map(value => value: String)
    override val sourceSecurityGroupOwnerId: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourceSecurityGroupOwnerId())
        .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.RevokeSecurityGroupEgressRequest
  ): zio.aws.ec2.model.RevokeSecurityGroupEgressRequest.ReadOnly = new Wrapper(
    impl
  )
}
